pub enum ConvertError {
ExpOperator(String),
UnsupportedOperator(String),
UnsupportedFunction(String),
RootNode(String),
ConstOperator(String),
VariableNotFound(String),
}Expand description
Errors that can occur during conversion from evalexpr AST to our internal AST representation.
This enum represents various failure modes when converting the evalexpr expression tree into our own AST format that can be used for JIT compilation and symbolic differentiation.
Variants
ExpOperator(String)
Error when trying to convert an exponent that is not a valid integer constant
UnsupportedOperator(String)
Error when encountering an operator that is not supported by our implementation
UnsupportedFunction(String)
Error when encountering a function that is not supported by our implementation
RootNode(String)
Error when the root node does not have exactly one child
ConstOperator(String)
Error when a constant value is not a floating point number
VariableNotFound(String)
Error when a variable is not found in the variable map