pub struct VarRef {
pub name: String,
pub vec_ref: Value,
pub index: u32,
}Expand description
Represents a reference to a variable in an expression.
Contains metadata needed to generate code that loads the variable’s value:
- The variable’s name as a string
- A Cranelift Value representing the pointer to the input array
- The variable’s index in the input array
Fields
name: Stringvec_ref: Valueindex: u32Trait Implementations
impl StructuralPartialEq for VarRef